@@ -6,36 +6,10 @@ from ray.rllib.utils import override
 from raylab.policy import TorchPolicy
 from raylab.policy.action_dist import WrapDeterministicPolicy
 from raylab.policy.losses import ClippedDoubleQLearning
-from raylab.policy.modules.critic.q_value import QValue
-from raylab.policy.modules.critic.q_value import QValueEnsemble
 from raylab.pytorch.nn.utils import update_polyak
 from raylab.pytorch.optim import build_optimizer
 
 
-class NAFValue(QValue):
-    """Wrapper around NAF."""
-
-    # pylint:disable=super-init-not-called,non-parent-init-called
-    def __init__(self, naf: nn.Module):
-        nn.Module.__init__(self)
-        self.naf = naf
-
-    def forward(self, obs, action):
-        return self.naf(obs, action)
-
-
-class TargetNAFValue(QValue):
-    """Wrapper around NAF's state-value function."""
-
-    # pylint:disable=super-init-not-called,non-parent-init-called
-    def __init__(self, naf_value: nn.Module):
-        nn.Module.__init__(self)
-        self.naf_value = naf_value
-
-    def forward(self, obs, action):
-        return self.naf_value(obs)
-
-
 class NAFTorchPolicy(TorchPolicy):
     """Normalized Advantage Function policy in Pytorch to use with RLlib."""
 
@@ -44,12 +18,8 @@ class NAFTorchPolicy(TorchPolicy):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        critics = QValueEnsemble([NAFValue(n) for n in self.module.critics])
-        target_critics = QValueEnsemble(
-            [TargetNAFValue(v) for v in self.module.target_vcritics]
-        )
         self.loss_fn = ClippedDoubleQLearning(
-            critics, target_critics, actor=lambda _: None
+            self.module.critics, self.module.target_vcritics
         )
         self.loss_fn.gamma = self.config["gamma"]
 
@@ -65,12 +35,7 @@ class NAFTorchPolicy(TorchPolicy):
     @override(TorchPolicy)
     def make_module(self, obs_space, action_space, config):
         module_config = config["module"]
-        module_config["type"] = "NAFModule-v0"
-        module_config["double_q"] = config["clipped_double_q"]
-        module_config["perturbed_policy"] = (
-            config["exploration_config"]["type"]
-            == "raylab.utils.exploration.ParameterNoise"
-        )
+        module_config["type"] = "NAF"
         # pylint:disable=no-member
         return super().make_module(obs_space, action_space, config)
 
