@@ -1,8 +1,10 @@
 """Primitives for all Trainers."""
 import copy
-import textwrap
+import inspect
 import warnings
 from abc import ABCMeta
+from collections import namedtuple
+from functools import partial
 from typing import Callable
 from typing import List
 from typing import Optional
@@ -19,11 +21,35 @@ from .config import Json
 from .config import with_rllib_info
 
 
-def config(
+ConfSetter = namedtuple("ConfSetter", "key setter")
+
+
+def configure(cls: type) -> type:
+    """Decorator for finishing the configuration setup for a Trainer class.
+
+    Should be called after all :func:`config` decorators have been applied,
+    i.e., as the top-most decorator.
+    """
+    # pylint:disable=protected-access
+    cls._default_config = copy.deepcopy(cls._default_config)
+    cls._config_info = copy.deepcopy(cls._config_info)
+    cls._allow_unknown_subkeys = copy.deepcopy(cls._allow_unknown_subkeys)
+    cls._override_all_subkeys_if_type_changes = copy.deepcopy(
+        cls._override_all_subkeys_if_type_changes
+    )
+
+    for conf_setter in sorted(cls._to_set, key=lambda x: x.key):
+        conf_setter.setter(cls)
+    cls._to_set = None
+
+    return cls
+
+
+def option(
     key: str,
     default: Json,
     *,
-    info: Optional[str] = None,
+    help: Optional[str] = None,
     override: bool = False,
     allow_unknown_subkeys: bool = False,
     override_all_if_type_changes: bool = False,
@@ -51,63 +77,92 @@ def config(
         RuntimeError: If attempting to enable `allow_unknown_subkeys` or
             `override_all_if_type_changes` options for non-toplevel keys
     """
-    # pylint:disable=protected-access,too-many-arguments
+    # pylint:disable=too-many-arguments,redefined-builtin
     if (allow_unknown_subkeys or override_all_if_type_changes) and separator in key:
         raise RuntimeError(
             "Cannot use 'allow_unknown_subkeys' or 'override_all_if_type_changes'"
             f" for non-toplevel key: '{key}'"
         )
-    key_seq = key.split(separator)
-    help_txt = info
 
-    def add_config(cls):
-        nonlocal key
-
-        if allow_unknown_subkeys and not override:
-            cls._allow_unknown_subkeys += [key]
-        if override_all_if_type_changes and not override:
-            cls._override_all_subkeys_if_type_changes += [key]
-
-        config_, info_ = cls._default_config, cls._config_info
-        for key in key_seq[:-1]:
-            config_ = config_[key]
-            if not isinstance(info_[key], dict):
-                info_[key] = {"__help__": info_[key]}
-            info_ = info_[key]
-        key = key_seq[-1]
-
-        if key in config_ and not override:
-            raise RuntimeError(
-                f"Attempted to override config key '{key}' but override=False."
-            )
-        if key in config_ and default == config_[key]:
-            raise RuntimeError(
-                f"Attempted to override config key {key} with the same value: {default}"
-            )
-        config_[key] = default
-
-        if help_txt is not None:
-            if key in info_ and not isinstance(info_[key], dict):
-                info_[key] = {"__help__": info_[key]}
-            info_[key] = textwrap.dedent(help_txt).rstrip()
+    setter = ConfSetter(
+        key=key,
+        setter=partial(
+            _set_config,
+            key=key,
+            default=default,
+            info=help,
+            override=override,
+            allow_unknown_subkeys=allow_unknown_subkeys,
+            override_all_if_type_changes=override_all_if_type_changes,
+            separator=separator,
+        ),
+    )
 
+    def add_setter(cls):
+        # pylint:disable=protected-access
+        if cls._to_set is None:
+            cls._to_set = []
+        cls._to_set += [setter]
         return cls
 
-    return add_config
+    return add_setter
 
 
-@config("compile_policy", False, info="Whether to optimize the policy's backend")
-@config(
+def _set_config(
+    cls: type,
+    key: str,
+    default: Json,
+    info: Optional[str] = None,
+    override: bool = False,
+    allow_unknown_subkeys: bool = False,
+    override_all_if_type_changes: bool = False,
+    separator: str = "/",
+):
+    # pylint:disable=too-many-arguments,protected-access
+    key_seq = key.split(separator)
+
+    if allow_unknown_subkeys and not override:
+        cls._allow_unknown_subkeys += [key]
+    if override_all_if_type_changes and not override:
+        cls._override_all_subkeys_if_type_changes += [key]
+
+    config_, info_ = cls._default_config, cls._config_info
+    for key_ in key_seq[:-1]:
+        config_ = config_.setdefault(key_, {})
+        info_ = info_.setdefault(key_, {})
+    key = key_seq[-1]
+
+    if key in config_ and not override:
+        raise RuntimeError(
+            f"Attempted to override config key '{key}' but override=False."
+        )
+    if key in config_ and default == config_[key]:
+        raise RuntimeError(
+            f"Attempted to override config key {key} with the same value: {default}"
+        )
+    config_[key] = default
+
+    if info is not None:
+        help_txt = inspect.cleandoc(info)
+        if isinstance(config_[key], dict):
+            info_[key] = {"__help__": help_txt}
+        else:
+            info_[key] = help_txt
+
+
+@configure
+@option("compile_policy", False, help="Whether to optimize the policy's backend")
+@option(
     "module",
     {},
-    info="Type and config of the PyTorch NN module.",
+    help="Type and config of the PyTorch NN module.",
     allow_unknown_subkeys=True,
     override_all_if_type_changes=True,
 )
-@config(
+@option(
     "torch_optimizer",
     {},
-    info="Config dict for PyTorch optimizers.",
+    help="Config dict for PyTorch optimizers.",
     allow_unknown_subkeys=True,
 )
 class Trainer(RLlibTrainer, metaclass=ABCMeta):
@@ -124,45 +179,36 @@ class Trainer(RLlibTrainer, metaclass=ABCMeta):
     optimizer isn't being used by the algorithm.
     """
 
-    evaluation_metrics: Optional[dict] = None
     optimizer: Optional[PolicyOptimizer]
     workers: Optional[WorkerSet]
-    _allow_unknown_subkeys: List[str] = copy.deepcopy(
-        RLlibTrainer._allow_unknown_subkeys
-    )
-    _override_all_subkeys_if_type_changes: List[str] = copy.deepcopy(
-        RLlibTrainer._override_all_subkeys_if_type_changes
-    )
+
+    _to_set: Optional[List[ConfSetter]] = None
     _config_info: Info = with_rllib_info({})
     _default_config: Config = with_rllib_config({})
 
+    def __init__(self, *args, **kwargs):
+        if self._to_set:
+            raise RuntimeError(
+                f"{self._name} Trainer still has configs to be set."
+                " Did you call `trainer.configure` as the last decorator?"
+            )
+        super().__init__(*args, **kwargs)
+
     @overrd(RLlibTrainer)
     def train(self):
         # Evaluate first, before any optimization is done
+        evaluation_metrics = None
         if self._iteration == 0 and self.config["evaluation_interval"]:
-            self.evaluation_metrics = self._evaluate()
+            evaluation_metrics = self._evaluate()
 
         result = super().train()
 
-        if self.evaluation_metrics:
-            result.update(self.evaluation_metrics)
+        if evaluation_metrics is not None:
+            result.update(evaluation_metrics)
         # Update global_vars after training so that they're saved if checkpointing
         self.global_vars["timestep"] = self.metrics.num_steps_sampled
         return result
 
-    @classmethod
-    def with_base_specs(cls, trainer_cls: type) -> type:
-        """Decorator for using this class' config and info in the given trainer."""
-        # pylint:disable=protected-access
-        trainer_cls._default_config = copy.deepcopy(cls._default_config)
-        trainer_cls._config_info = copy.deepcopy(cls._config_info)
-        trainer_cls._allow_unknown_subkeys = copy.deepcopy(cls._allow_unknown_subkeys)
-        trainer_cls._override_all_subkeys_if_type_changes = copy.deepcopy(
-            cls._override_all_subkeys_if_type_changes
-        )
-
-        return trainer_cls
-
     def _setup(self, *args, **kwargs):
         cls_attrs = ("_allow_unknown_subkeys", "_override_all_subkeys_if_type_changes")
         attr_cache = ((attr, getattr(RLlibTrainer, attr)) for attr in cls_attrs)
@@ -183,6 +229,10 @@ class Trainer(RLlibTrainer, metaclass=ABCMeta):
                     "No worker set initialized; episodes summary will be unavailable."
                 )
 
+        # Always have a WorkerSet to get workers and policy
+        if hasattr(self, "optimizer") and not hasattr(self, "workers"):
+            self.workers = self.optimizer.workers
+
         if self.config["compile_policy"]:
             if not hasattr(self, "workers"):
                 raise RuntimeError(
